@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011,2012
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013
  *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  * Copyright (C) 2011 Luis Ángel Fernández Fernández <laffdez@gmail.com>
  */
@@ -592,7 +592,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		if (!email.isEmpty())
 			page->kURLRequester1->setUrl(QString(revurl + email.section(QLatin1Char( '@' ), 0, 0) + QLatin1String( ".revoke" )));
 		else
-			page->kURLRequester1->setUrl(QString(revurl + genkey->getName().section(QLatin1Char(' '), 0, 0) + QLatin1String(".revoke")));
+			page->kURLRequester1->setUrl(QString(revurl + email.section(QLatin1Char( ' ' ), 0, 0) + QLatin1String( ".revoke" )));
 
 		const QString fingerprint(genkey->getFingerprint());
 		page->TLid->setText(QLatin1String( "<b>" ) + fingerprint.right(8) + QLatin1String( "</b>" ));
@@ -602,8 +602,11 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		keyCreated->setMainWidget(page);
 
 		keyCreated->exec();
-		if (keyCreated.isNull())
+		if (keyCreated.isNull()) {
 			return;
+		} else {
+			delete keyCreated;
+		}
 
 		imodel->refreshKey(fingerprint);
 		KGpgKeyNode *knode = imodel->getRootNode()->findKey(fingerprint);
@@ -627,7 +630,6 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 
 			genRev->start();
 		}
-		delete keyCreated;
 		break;
 	}
 	default:
@@ -1703,8 +1705,7 @@ void KeysManager::editGroup()
 
 	QList<KGpgNode *> members(gnd->getChildren());
 
-	groupEdit *gEdit = new groupEdit(dialogGroupEdit, &members);
-	gEdit->setModel(imodel);
+	groupEdit *gEdit = new groupEdit(dialogGroupEdit, &members, imodel);
 
 	dialogGroupEdit->setMainWidget(gEdit);
 
@@ -2119,7 +2120,7 @@ void KeysManager::delsignkey()
 		parentKey = parent->getParentKeyNode()->getId();
 		break;
 	default:
-		Q_ASSERT(1);
+		Q_ASSERT(0);
 		return;
 	}
 
